Class: Maglev::GetPageSections
- Inherits:
-
Object
- Object
- Maglev::GetPageSections
- Includes:
- Injectable, TransformSectionConcern
- Defined in:
- app/services/maglev/get_page_sections.rb
Overview
Get the content of a page in a specific locale. The content comes from the sections of the page. Also replace the links by their real values based on the context (live editing or not).
Defined Under Namespace
Modules: TransformCollectionItemConcern, TransformLinkConcern, TransformSectionConcern, TransformTextConcern
Instance Method Summary collapse
Instance Method Details
#call ⇒ Object
21 22 23 24 25 |
# File 'app/services/maglev/get_page_sections.rb', line 21 def call sections.map do |section| transform_section(section.dup) end.compact end |